@@ -3,8 +3,9 @@
 
 #include <QDialog>
 #include <QtGui>
+#if defined(Q_WS_MAEMO_5) || defined(Q_WS_HILDON)
 #include "qmaemo5rotator.h"
-
+#endif
 class grooveProgressBar : public QDialog
 {
     Q_OBJECT
@@ -13,7 +14,9 @@ public:
     void setMaximum(int maximum);
     void setValue(int position);
     int maximum();
+#if defined(Q_WS_MAEMO_5) || defined(Q_WS_HILDON)
     QMaemo5Rotator *rot;
+#endif
 
 signals:
 
